@@ -16,6 +16,12 @@ for file in ${ocp_fluentd_files} ; do
     sed -i -e "s/%OCP_FLUENTD_TAGS%/${OCP_FLUENTD_TAGS}/" $file
 done
 
+echo "============================="
+echo "Fluentd logs have been redirected to: $LOGGING_FILE_PATH"
+echo "If you want to print out the logs, use command:"
+echo "oc exec <pod_name> $HOME/utils/logs"
+echo "============================="
+
 fluentdargs="--no-supervisor"
 if [[ $VERBOSE ]]; then
   set -ex
@@ -56,7 +62,7 @@ docker_uses_journal() {
         if grep -q '^[^#].*"log-driver":.*journald' /etc/docker/daemon.json 2> /dev/null ; then
             return 0
         fi
-    elif grep -q "^OPTIONS='[^']*--log-driver=journald" /etc/sysconfig/docker 2> /dev/null ; then
+    elif grep -q "^OPTIONS='[^']*--log-driver[   =][     ]*journald" /etc/sysconfig/docker 2> /dev/null ; then
         return 0
     fi
     return 1
@@ -180,6 +186,11 @@ if [ -n "${MUX_CLIENT_MODE:-}" ] ; then
     if [ -n "$output_label" ]; then
         cp $CFG_DIR/{,openshift}/filter-post-z-mux-client.conf
     fi
+    # Enable "output-es-ops-config.conf in output-operations.conf"
+    # we need something there so output-operations.conf won't have an empty @copy without a <store> block
+    # but it won't actually be used in this case - output-pre-mux-client.conf will match everything
+    # before we get here
+    cp $CFG_DIR/{openshift,dynamic}/output-es-ops-config.conf
 else
     # check ES_HOST vs. OPS_HOST; ES_PORT vs. OPS_PORT
     if [ "$ES_HOST" = ${OPS_HOST:-""} -a $ES_PORT -eq ${OPS_PORT:-0} ]; then
@@ -316,7 +327,8 @@ if [[ "${USE_REMOTE_SYSLOG:-}" = "true" ]] ; then
     fi
 fi
 
-if [ "${TRANSFORM_EVENTS:-}" != true ] ; then
+# Disable process_kubernetes_events if TRANSFORM_EVENTS is false or MUX client.
+if [ "${TRANSFORM_EVENTS:-}" != true -o -n "${MUX_CLIENT_MODE:-}" ] ; then
     sed -i 's/\(.*@type viaq_data_model.*\)/\1\n  process_kubernetes_events false/' $CFG_DIR/openshift/filter-viaq-data-model.conf
 fi
 
@@ -350,6 +362,9 @@ if [ "${ENABLE_PROMETHEUS_ENDPOINT}" != "true" ] ; then
   rm -f ${CFG_DIR}/openshift/input-pre-prometheus-metrics.conf
 fi
 
+# Create a directory for Fluentd log files
+mkdir -p /var/log/fluentd/
+
 issue_deprecation_warnings
 if [[ $DEBUG ]] ; then
     exec fluentd $fluentdargs > /var/log/fluentd.log 2>&1
